package com.xkrs.service.impl;

import com.xkrs.dao.QcInspectionDataSourceDao;
import com.xkrs.dao.QcInspectionItemDictDao;
import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.model.entity.QcInspectionDataSourceEntity;
import com.xkrs.model.entity.QcInspectionItemDictEntity;
import com.xkrs.model.qo.QcInspectionDataSourceQo;
import com.xkrs.service.QcInspectionDataSourceService;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.util.Locale;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/19 16:43
 */
@Service
public class QcInspectionDataSourceServiceImpl implements QcInspectionDataSourceService {

    @Resource
    private QcInspectionDataSourceDao inspectionDataSourceDao;

    @Resource
    private QcInspectionItemDictDao inspectionItemDictDao;

    /**
     * 添加测量数据
     *
     * @param inspectionDataSourceQo
     * @return
     */
    @Override
    public String insertDataSource(QcInspectionDataSourceQo inspectionDataSourceQo) {
        Locale locale = LocaleContextHolder.getLocale();
        QcInspectionItemDictEntity byInspectionItemCode = inspectionItemDictDao.findByInspectionItemCode(inspectionDataSourceQo.getInspectionItemCode());
        if (byInspectionItemCode == null) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "不存在该字典类型！", locale);
        }
        QcInspectionDataSourceEntity qcInspectionDataSourceEntity = new QcInspectionDataSourceEntity();
        if (inspectionDataSourceQo.getId() > 0) {
            qcInspectionDataSourceEntity.setId(inspectionDataSourceQo.getId());
        }
        qcInspectionDataSourceEntity.setLotNo(inspectionDataSourceQo.getLotNo());
        qcInspectionDataSourceEntity.setMachineNo(inspectionDataSourceQo.getMachineNo());
        qcInspectionDataSourceEntity.setMaterialNo(inspectionDataSourceQo.getMaterialNo());
        qcInspectionDataSourceEntity.setModelNo(inspectionDataSourceQo.getModelNo());
        qcInspectionDataSourceEntity.setPartNo(inspectionDataSourceQo.getPartNo());
        qcInspectionDataSourceEntity.setInspectionItemCode(inspectionDataSourceQo.getInspectionItemCode());
        qcInspectionDataSourceEntity.setInspectValue(inspectionDataSourceQo.getInspectValue());
        inspectionDataSourceDao.save(qcInspectionDataSourceEntity);
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "添加成功！", locale);
    }
}
